@@ -7,11 +7,13 @@ Assumed input units are erg/s/cm^2/AA and AA
 """
 
 import numpy as np
-import os
 try:
-    from pkg_resources import resource_filename, resource_listdir
+    from numpy import trapezoid
 except(ImportError):
-    pass
+    from numpy import trapz as trapezoid
+
+import os
+from importlib.resources import files
 from .reference_spectra import vega, solar, sedpydir
 
 
@@ -24,7 +26,7 @@ lightspeed = 2.998e18  # AA/s
 
 
 class Filter(object):
-    """This class operates on filter transmission files.  It reads simple
+    r"""This class operates on filter transmission files.  It reads simple
     2-column ascii files containing filter transmission curves. It caches a
     number of useful filter quantities.  Methods are provided to project a
     source spectrum onto the filter and return the magnitude, AB or Vega.
@@ -85,8 +87,9 @@ class Filter(object):
         if directory is None:
             loc = os.path.join('data', 'filters', kname + '.par')
             try:
-                self.filename = resource_filename("sedpy", loc)
-            except:
+                data_files = files('sedpy') / 'data' / 'filters'
+                self.filename = str(data_files / (kname + '.par'))
+            except Exception:
                 self.filename = os.path.join(sedpydir, loc)
         else:
             self.filename = os.path.join(directory, kname+'.par')
@@ -238,13 +241,13 @@ class Filter(object):
         of many of these quantities.
         """
         # Calculate some useful integrals
-        i0 = np.trapz(self.transmission * np.log(self.wavelength),
+        i0 = trapezoid(self.transmission * np.log(self.wavelength),
                       np.log(self.wavelength))
-        i1 = np.trapz(self.transmission,
+        i1 = trapezoid(self.transmission,
                       np.log(self.wavelength))
-        i2 = np.trapz(self.transmission * self.wavelength,
+        i2 = trapezoid(self.transmission * self.wavelength,
                       self.wavelength)
-        i3 = np.trapz(self.transmission,
+        i3 = trapezoid(self.transmission,
                       self.wavelength)
 
         tmax = self.transmission.max()
@@ -262,14 +265,14 @@ class Filter(object):
         rind = np.argmin(self.wavelength[sel])
         self.red_edge = self.wavelength[sel][rind]
 
-        i4 = np.trapz(self.transmission *
+        i4 = trapezoid(self.transmission *
                       (np.log(self.wavelength / self.wave_effective))**2.0,
                       np.log(self.wavelength))
         self.gauss_width = (i4 / i1)**(0.5)
         self.effective_width = (2.0 * np.sqrt(2. * np.log(2.)) *
                                 self.gauss_width *
                                 self.wave_effective)
-        # self.norm  = np.trapz(transmission,wavelength)
+        # self.norm  = trapezoid(transmission,wavelength)
 
         # Get zero points and AB to Vega conversion
         self.ab_zero_counts = self.obj_counts(self.wavelength,
@@ -340,7 +343,7 @@ class Filter(object):
             # assert ~edge, "Source spectrum does not span filter."
             ind = slice(max(positive.min() - 1, 0),
                         min(positive.max() + 2, len(sourcewave)))
-            counts = np.trapz(sourcewave[ind] * newtrans[ind] *
+            counts = trapezoid(sourcewave[ind] * newtrans[ind] *
                               sourceflux[..., ind],
                               sourcewave[ind], axis=-1)
             return np.squeeze(counts)
@@ -376,7 +379,7 @@ class Filter(object):
 
         # Integrate lambda*f_lambda*R
         if True in (newflux > 0.):
-            counts = np.trapz(self.wavelength * self.transmission * newflux,
+            counts = trapezoid(self.wavelength * self.transmission * newflux,
                               self.wavelength)
             return np.squeeze(counts)
         else:
@@ -557,14 +560,14 @@ class FilterSet(object):
                                     dlnlam=self.dlnlam, **loading_kwargs)
 
     def _build_super_trans(self):
-        """Build the global gridded transmission array. Populates FilterSet.trans, which
+        r"""Build the global gridded transmission array. Populates FilterSet.trans, which
         is an array of shape (nfilters, nlam) giving :math:`T\times \lambda \times
         d\lambda / Z` where `T` is the detector signal per photon and `Z` is the
         detector signal for a 1 maggie source
         """
         # TODO: investigate using arrays that cover different wavelength
         # intervals (but same number of elements) for each filter. Then when
-        # integrating (with dot or vectorized trapz) the source spectrum must be
+        # integrating (with dot or vectorized trapezoid) the source spectrum must be
         # offset for each filter. This would remove the vast majority of zeros
 
         ab_counts = np.array([f.ab_zero_counts for f in self.filters])
@@ -664,7 +667,7 @@ class FilterSet(object):
             flux = sourceflux
         y = self.trans_dw * flux[self.finds]
         x = self.lam[self.finds]
-        maggies = np.trapz(y, x, axis=-1)
+        maggies = trapezoid(y, x, axis=-1)
         return maggies
 
     def get_sed_maggies_numba(self, sourceflux, sourcewave=None):
@@ -810,11 +813,12 @@ def list_available_filters():
     have been installed in the sedpy/data/filters/ directory.
     """
     try:
-        names = resource_listdir('sedpy', '/data/filters/')
-    except:
-        names = os.listdir(os.path.join(sedpydir, '/data/filters/'))
+        data_files = files('sedpy') / 'data' / 'filters'
+        names = [f.name for f in data_files.iterdir() if f.is_file()]
+    except Exception:
+        names = os.listdir(os.path.join(sedpydir, 'data', 'filters'))
 
-    parfiles = [n.replace('.par', '') for n in names if n[-4:] == '.par']
+    parfiles = [n.replace('.par', '') for n in names if n.endswith('.par')]
     parfiles.sort()
     return parfiles
 
@@ -854,7 +858,7 @@ def Lbol(wave, spec, wave_min=90, wave_max=1e6):
        of length (...nsource)
     """
     inds = np.where(np.logical_and(wave < wave_max, wave >= wave_min))
-    return np.trapz(spec[..., inds[0]], wave[inds])
+    return trapezoid(spec[..., inds[0]], wave[inds])
 
 
 def air2vac(air):
